@@ -1,5 +1,7 @@
 # 2016-07-20:  Added support for power transformations in lmerMod  objects, S. Weisberg
 # 2016-05-02:  Moved (working) cosde for bncPower family to bcnPower.R
+# 2017-12-19:  Modified estimateTransform to handle gamma \approx 0 gracefully.
+# 2017-12-19:  added error for 'I' terms in formulas
 
 # generic functions in powerTransform.R
 
@@ -15,6 +17,9 @@ powerTransform.lmerMod <- function(object, family="bcPower", ...) {
 # lmerMod
 estimateTransform.lmerMod <- function(object, family="bcPower", lambda=c(-3, 3), start=NULL, method="L-BFGS-B", ...) {
   data <- model.frame(object)
+  if(any(unlist(lapply(as.list(data), class)) == "AsIs")) stop(
+    "powerTransform for lmer models don't work with the 'I' function; rewrite your formula"
+  )
   y <- (object@resp)$y
   fam <- match.fun(family)
   llik <- function(lambda){
@@ -23,7 +28,8 @@ estimateTransform.lmerMod <- function(object, family="bcPower", lambda=c(-3, 3),
     logLik(m.lambda)
   }
   if (is.null(start)) start <- 1
-  res<- optimize(f = function(lambda1) llik(lambda1), lower=lambda[1], upper=lambda[2], maximum=TRUE)
+  res<- optimize(f = function(lambda1) llik(lambda1), lower=lambda[1], upper=lambda[2],
+                 maximum=TRUE)
 # optimize does not give the Hessian, so run optimHess
   res$hessian <- optimHess(res$maximum, llik, ...)
   res$invHess <- solve(-res$hessian)
@@ -62,17 +68,9 @@ testTransform.lmerModpowerTransform <- function(object, lambda=1){
   LR <- c(2 * (object$value - llik))
   df <- 1
   pval <- 1-pchisq(LR, df)
-  out <- data.frame(LRT=LR, df=df, pval=pval)
+  out <- data.frame(LRT=LR, df=df, pval=format.pval(pval))
   rownames(out) <-
     c(paste("LR test, lambda = (",
             paste(round(lambda, 2), collapse=" "), ")", sep=""))
   out}
 
-
-
-###########################################################################
-# plot method
-###########################################################################
-# lmerMod
-plot.lmerModpowerTransform <- function(x, z, round=TRUE, plot=pairs, ...){
-  cat("plot not supported for mixed models\n") }
